@@ -1,14 +1,19 @@
-/// Asserts that two vectors have the same length and approximately equal values.
+/// Asserts that two vectors have the same length and approximately equal values
 ///
-/// On panic, this macro will print the values of the expressions with their
-/// debug representations.
+/// # Input
 ///
-/// A tolerance must be given for the absolute comparison of float-point numbers.
+/// `a` -- Left vector
+/// `b` -- Right vector
+/// `tol: f64` -- Error tolerance such that `|a[i] - b[i]| < tol` for all `i in [0,a.len()]`
 ///
-/// Code inspired by [assert_approx_eq](https://github.com/ashleygwilliams/assert_approx_eq)
+/// # Note
+///
+/// This macro also checks that a.len() == b.len()
 ///
 /// # Examples
 ///
+/// ## Accepts small error
+///
 /// ```
 /// # #[macro_use] extern crate russell_chk;
 /// # fn main() {
@@ -18,6 +23,19 @@
 /// # }
 /// ```
 ///
+/// ## Panics on different values
+///
+/// ```should_panic
+/// # #[macro_use] extern crate russell_chk;
+/// # fn main() {
+/// let a = [1.0, 2.0, 3.0];
+/// let b = [1.0, 2.0, 4.0];
+/// assert_vec_approx_eq!(a, b, 1e-6);
+/// # }
+/// ```
+///
+/// ## Panics on different lengths
+///
 /// ```should_panic
 /// # #[macro_use] extern crate russell_chk;
 /// # fn main() {
@@ -62,7 +80,7 @@ mod tests {
     #[test]
     #[should_panic(expected = "assertion failed: `(left.len() != right.len())` \
                                (left: `[1.0, 2.0]`, right: `[1.0]`)")]
-    fn it_should_panic_on_different_lengths() {
+    fn panics_on_different_lengths() {
         assert_vec_approx_eq!(&[1.0, 2.0], &[1.0], 1e-1);
     }
 
@@ -70,14 +88,14 @@ mod tests {
     #[should_panic(expected = "assertion failed: `(left[1] != right[1])` \
                                (left[1]: `2.0`, right[1]: `2.5`, \
                                expect diff: `0.1`, real diff: `0.5`)")]
-    fn it_should_panic_on_different_values() {
+    fn panics_on_different_values() {
         assert_vec_approx_eq!(&[1.0, 2.0], &[1.0, 2.5], 1e-1);
     }
 
     #[test]
     #[should_panic(expected = "assertion failed: `(left.len() != right.len())` \
                                (left: `[1.0, 2.0]`, right: `[1.0]`)")]
-    fn it_should_panic_on_different_lengths_f32() {
+    fn panics_on_different_lengths_f32() {
         assert_vec_approx_eq!(&[1f32, 2f32], &[1f32], 1e-1);
     }
 
@@ -85,17 +103,17 @@ mod tests {
     #[should_panic(expected = "assertion failed: `(left[1] != right[1])` \
                                (left[1]: `2.0`, right[1]: `2.5`, \
                                expect diff: `0.1`, real diff: `0.5`)")]
-    fn it_should_panic_on_different_values_f32() {
+    fn panics_on_different_values_f32() {
         assert_vec_approx_eq!(&[1f32, 2f32], &[1f32, 2.5f32], 1e-1);
     }
 
     #[test]
-    fn it_should_accept_approx_equal_values() {
-        assert_vec_approx_eq!(&[1.0, 2.0], &[1.0, 2.01], 1e-2);
+    fn accepts_approx_equal_values() {
+        assert_vec_approx_eq!(&[1.0, 2.0], &[1.0, 2.02], 0.03);
     }
 
     #[test]
-    fn it_should_accept_approx_equal_values_f32() {
-        assert_vec_approx_eq!(&[1f32, 2f32], &[1f32, 2.01f32], 1e-2);
+    fn accepts_approx_equal_values_f32() {
+        assert_vec_approx_eq!(&[1f32, 2f32], &[1f32, 2.02f32], 0.03);
     }
 }
